IconConfig class

Constructors

IconConfig({required String imagePath, required bool generateAndroid, required bool generateIos, required bool generateWeb, required bool generateWindows, required bool generateMacos, required bool generateLinux, String? androidIconName, bool? adaptiveIcon, String? adaptiveForeground, String? adaptiveBackground})
const
IconConfig.fromFile(String configPath)
factory

Properties

adaptiveBackground String?
final
adaptiveForeground String?
final
adaptiveIcon bool?
final
androidIconName String?
final
generateAndroid bool
final
generateIos bool
final
generateLinux bool
final
generateMacos bool
final
generateWeb bool
final
generateWindows bool
final
hashCode int
The hash code for this object.
no setterinherited
imagePath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited